@@ -605,7 +605,7 @@ def cli_parser():
         help='Give extra arguments to diffoscope when running it. Default: '
         '%(default)s. Arguments are {}-formatted with: {0} the name of each '
         'experiment run, and {1} the path of the experiment output.',
-        default=['--exclude-directory-metadata'])
+        default=['--exclude-directory-metadata=yes'])
     group2.add_argument('--diffoscope', default='diffoscope', metavar='PATH',
         help='Path to diffoscope(1). Default: %(default)s')
     group2.add_argument('--no-diffoscope', action='store_true', default=False,
